@@ -18,11 +18,12 @@ from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import PlaybackModeType
+from .literals import PlaybackModeType, TierType
 from .paginator import (
     GetChannelSchedulePaginator,
     ListAlertsPaginator,
     ListChannelsPaginator,
+    ListLiveSourcesPaginator,
     ListPlaybackConfigurationsPaginator,
     ListPrefetchSchedulesPaginator,
     ListSourceLocationsPaginator,
@@ -36,6 +37,7 @@ from .type_defs import (
     CdnConfigurationTypeDef,
     ConfigureLogsForPlaybackConfigurationResponseTypeDef,
     CreateChannelResponseTypeDef,
+    CreateLiveSourceResponseTypeDef,
     CreatePrefetchScheduleResponseTypeDef,
     CreateProgramResponseTypeDef,
     CreateSourceLocationResponseTypeDef,
@@ -43,6 +45,7 @@ from .type_defs import (
     DashConfigurationForPutTypeDef,
     DefaultSegmentDeliveryConfigurationTypeDef,
     DescribeChannelResponseTypeDef,
+    DescribeLiveSourceResponseTypeDef,
     DescribeProgramResponseTypeDef,
     DescribeSourceLocationResponseTypeDef,
     DescribeVodSourceResponseTypeDef,
@@ -54,6 +57,7 @@ from .type_defs import (
     HttpPackageConfigurationTypeDef,
     ListAlertsResponseTypeDef,
     ListChannelsResponseTypeDef,
+    ListLiveSourcesResponseTypeDef,
     ListPlaybackConfigurationsResponseTypeDef,
     ListPrefetchSchedulesResponseTypeDef,
     ListSourceLocationsResponseTypeDef,
@@ -69,6 +73,7 @@ from .type_defs import (
     SegmentDeliveryConfigurationTypeDef,
     SlateSourceTypeDef,
     UpdateChannelResponseTypeDef,
+    UpdateLiveSourceResponseTypeDef,
     UpdateSourceLocationResponseTypeDef,
     UpdateVodSourceResponseTypeDef,
 )
@@ -137,7 +142,8 @@ class MediaTailorClient(BaseClient):
         Outputs: Sequence["RequestOutputItemTypeDef"],
         PlaybackMode: PlaybackModeType,
         FillerSlate: "SlateSourceTypeDef" = ...,
-        Tags: Mapping[str, str] = ...
+        Tags: Mapping[str, str] = ...,
+        Tier: TierType = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Creates a channel.
@@ -146,6 +152,21 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#create_channel)
         """
 
+    def create_live_source(
+        self,
+        *,
+        HttpPackageConfigurations: Sequence["HttpPackageConfigurationTypeDef"],
+        LiveSourceName: str,
+        SourceLocationName: str,
+        Tags: Mapping[str, str] = ...
+    ) -> CreateLiveSourceResponseTypeDef:
+        """
+        Creates name for a specific live source in a source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.create_live_source)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#create_live_source)
+        """
+
     def create_prefetch_schedule(
         self,
         *,
@@ -169,8 +190,9 @@ class MediaTailorClient(BaseClient):
         ProgramName: str,
         ScheduleConfiguration: "ScheduleConfigurationTypeDef",
         SourceLocationName: str,
-        VodSourceName: str,
-        AdBreaks: Sequence["AdBreakTypeDef"] = ...
+        AdBreaks: Sequence["AdBreakTypeDef"] = ...,
+        LiveSourceName: str = ...,
+        VodSourceName: str = ...
     ) -> CreateProgramResponseTypeDef:
         """
         Creates a program.
@@ -227,6 +249,14 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_channel_policy)
         """
 
+    def delete_live_source(self, *, LiveSourceName: str, SourceLocationName: str) -> Dict[str, Any]:
+        """
+        Deletes a specific live source in a specific source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.delete_live_source)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_live_source)
+        """
+
     def delete_playback_configuration(self, *, Name: str) -> Dict[str, Any]:
         """
         Deletes the playback configuration for the specified name.
@@ -277,6 +307,16 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#describe_channel)
         """
 
+    def describe_live_source(
+        self, *, LiveSourceName: str, SourceLocationName: str
+    ) -> DescribeLiveSourceResponseTypeDef:
+        """
+        Provides details about a specific live source in a specific source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.describe_live_source)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#describe_live_source)
+        """
+
     def describe_program(
         self, *, ChannelName: str, ProgramName: str
     ) -> DescribeProgramResponseTypeDef:
@@ -383,6 +423,16 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_channels)
         """
 
+    def list_live_sources(
+        self, *, SourceLocationName: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListLiveSourcesResponseTypeDef:
+        """
+        lists all the live sources in a source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_live_sources)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_live_sources)
+        """
+
     def list_playback_configurations(
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListPlaybackConfigurationsResponseTypeDef:
@@ -517,6 +567,20 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_channel)
         """
 
+    def update_live_source(
+        self,
+        *,
+        HttpPackageConfigurations: Sequence["HttpPackageConfigurationTypeDef"],
+        LiveSourceName: str,
+        SourceLocationName: str
+    ) -> UpdateLiveSourceResponseTypeDef:
+        """
+        Updates a specific live source in a specific source location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.update_live_source)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_live_source)
+        """
+
     def update_source_location(
         self,
         *,
@@ -570,6 +634,15 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_live_sources"]
+    ) -> ListLiveSourcesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_playback_configurations"]
